@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-package Task::Kensho::WebDev; # git description: v0.39-62-g2e22437
+package Task::Kensho::WebDev; # git description: v0.40-22-gbd662b9
 # ABSTRACT: A Glimpse at an Enlightened Perl: Web Development
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 __END__
 
@@ -17,7 +17,7 @@ Task::Kensho::WebDev - A Glimpse at an Enlightened Perl: Web Development
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -110,6 +110,10 @@ Catalyst is The Elegant MVC Web Application Framework. Task::Catalyst is all you
 
 (Template::Toolkit) Template Processing System
 
+=head3 L<Web::Simple>
+
+A quick and easy way to build simple web applications
+
 =head3 L<XML::Atom>
 
 Atom feed and API implementation
@@ -144,7 +148,7 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
+Bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
 There is also an irc channel available for users of this distribution, at
 L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
@@ -155,7 +159,7 @@ Chris Prather <chris@prather.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Olaf Alders Dan Book Rachel Kelly Shawn Sorichetti Rick Leir
+=for stopwords Karen Etheridge Leo Lapworth Dan Book Chris Nehren Mohammad S Anwar Olaf Alders Rachel Kelly Shawn Sorichetti Rick Leir Tina Müller
 
 =over 4
 
@@ -169,10 +173,18 @@ Leo Lapworth <leo@cuckoo.org>
 
 =item *
 
+Dan Book <grinnz@grinnz.com>
+
+=item *
+
 Chris Nehren <apeiron@cpan.org>
 
 =item *
 
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -191,6 +203,10 @@ Shawn Sorichetti <shawn@coloredblocks.com>
 
 Rick Leir <rleir@leirtech.com>
 
+=item *
+
+Tina Müller <cpan2@tinita.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
